"""
remotefunc - Simple RPC library for calling functions across processes
"""

from .decorator import shared
from .server import get_server_port, shutdown_server
from .client import configure

__all__ = ['shared', 'get_server_port', 'shutdown_server', 'configure']
__version__ = '0.1.0'
